package com.ruoyi.doubledefense.service;

import java.util.List;
import com.ruoyi.doubledefense.domain.Device;
import com.ruoyi.doubledefense.dto.DeviceDTO;
import com.ruoyi.doubledefense.dto.DeviceStatisticsPCDTO;
import com.ruoyi.doubledefense.dto.res.DeviceResultDTO;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-08-03
 */
public interface IDeviceService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public DeviceResultDTO selectDeviceById(String id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param device 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<DeviceResultDTO> selectDeviceList(DeviceDTO device);

    /**
     * 新增【请填写功能名称】
     *
     * @param device 【请填写功能名称】
     * @return 结果
     */
    public int insertDevice(DeviceDTO device);

    /**
     * 修改【请填写功能名称】
     *
     * @param device 【请填写功能名称】
     * @return 结果
     */
    public int updateDevice(DeviceDTO device);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteDeviceByIds(String[] ids);

    /**
     *
     * PC首页-设备管理统计
     * @param companyCode
     * @return
     */
    DeviceStatisticsPCDTO deviceStatistics(String companyCode);
}
